(* ------------------- PBM2.INC ------------------------

  Include file to load a screen dump from a PBM (portable bitmap) file.
  Provides the following functions:

    procedure LoadScreenFromPBM -> Get image row from a PBM file
                                   and copy it to the Roller RAM

  Uses include file KERNEL.INC.

  ---------------------------------------------------- *)
const
  BufSize = 128;

type
  TFileName  = string(.14.);
  BinaryFile = file;

var
  fbuf   :  Array(.1..BufSize.) of byte;
  fbufidx:  byte;
  recsread: integer;
  pbmfile:  BinaryFile;
(*   cnt: integer; (* TEST *)


(* Reads a byte from the buffer. Reads a block from disc
   as soon as the buffer is read to the end. *)
function ReadBuf: byte;
(* var b: byte; i: integer; (* TEST *)
begin
  if fbufidx = BufSize then begin
    fbufidx := 1;
(* WriteLn('Before BlockRead'); (* TEST *)
    BlockRead(pbmfile, fbuf, 1, recsread); (* reads a block of 128 bytes *)
(* WriteLn('After BlockRead'); (* TEST *)
(*     Writeln('recsread: ', recsread); (* TEST *)
  end
  else
    fbufidx := succ(fbufidx);
(* b := fbuf(.fbufidx.);
i := b;
WriteLn('ReadBuf: ', i); (* TEST *
cnt := succ(cnt);
if cnt > 10 then begin
    cnt := 0;
    WaitForKey;
end;
*)
  ReadBuf := fbuf(.fbufidx.);
end; (* ReadBuf *)

(* Checks whether the next value from the buffer equals
   the byte in the parameter. *)
function EqualsNextBufVal(b: byte): boolean;
begin
    EqualsNextBufVal := (ReadBuf = b);
end; (* EqualsNextBufVal *)

(* Loads a screen dump from a black and white 1 bit per pixel PBM file. *)
procedure LoadScreenFromPBM(filename: TFileName);
var
  row      : byte;
  x, y     : byte;
  i        : integer;
begin
(* WriteLn('LoadScreenFromPBM start'); (* TEST *)
  fbufidx := BufSize;
(*   cnt := 0; (* TEST *)

  Assign(pbmfile, filename);
  (*$I-*)
  Reset(pbmfile);
  (*$I+*)
  if IOResult = 0 then begin
(* WriteLn('LoadScreenFromPBM IOResult = 0'); (* TEST *)

    (* Read header *)
    if EqualsNextBufVal($50) and (* 'P' *)
       EqualsNextBufVal($34) and (* '4' *)
       EqualsNextBufVal($0A) and (* LF  *)
       EqualsNextBufVal($37) and (* '7' *)
       EqualsNextBufVal($32) and (* '2' *)
       EqualsNextBufVal($30) and (* '0' *)
       EqualsNextBufVal($0A) and (* ' ' *)
       EqualsNextBufVal($32) and (* '2' *)
       EqualsNextBufVal($35) and (* '5' *)
       EqualsNextBufVal($36) and (* '6' *)
       EqualsNextBufVal($0A)     (* LF  *)
                                 (* TODO $F7 ? *)
    then begin
(* WriteLn('Read header ok'); (* TEST *)
      (* Read pixel data *)
      for row := 0 to 31 do begin
(* WriteLn('Current row: ', row); (* TEST *)
        for y := 0 to 7 do begin
          i := y;
          for x := 1 to 90 do begin (* 90 = 720 / 8 *)
            GX_Buffer(.i.) := ReadBuf;
            i := i + 8;
          end;
        end;
        PutScreenRow(row); (* puts 720 bytes = 8 rows of 90 bytes *)
      end;
    end;
    
    Close(pbmfile);
  end;
(* WriteLn('LoadScreenFromPBM end'); (* TEST *)
end; (* LoadScreenFromPBM *)
